from RPi import GPIO
from time import sleep


class RotarySwitch:


    def __init__(self, pin_sta_clk, pin_sta_dt, callback_client):
        # Input parameters
        #   - pins number of clk and dt
        #   - client function to call when rotation is detected
        #

        self.pin_sta_clk = pin_sta_clk
        self.pin_sta_dt = pin_sta_dt
        self.callback_client = callback_client
        self.clockwise = True
        
        # Set up pins
        GPIO.setup(self.pin_sta_clk, GPIO.IN, pull_up_down=GPIO.PUD_UP)
        GPIO.setup(self.pin_sta_dt, GPIO.IN, pull_up_down=GPIO.PUD_UP)

        # Add callback procedure when rotary switch is turning
        GPIO.add_event_detect(pin_sta_dt, GPIO.FALLING, callback=self.turnEventHandler, bouncetime=300)  


    def turnEventHandler(self, channel):
        #
        #
        try:
            clkState = GPIO.input(self.pin_sta_clk)
            dtState = GPIO.input(self.pin_sta_dt)
            if dtState != clkState:
                self.clockwise = True
                print("clockwise")
            else:
                self.clockwise = False
                print("anticlockwise")
            self.callback_client(self.clockwise)      
            sleep(0.01)
        except IOError:
            print ("Error")
            



 
    def isClockwise(self):
        #
        #
        return self.clockwise